require(phangorn)
	
	MFSIM<-function(mat,seed,al,n,name,founder_seqs,training=1,tmat=F,indel=F,founder_max=T,write=F,dif_prop=F,prop){
	
	if(is.character(seed)==F)
	stop('seed sequence is not a character string')
	
	if(is.character(al)==F)
	stop('al is not a character matrix')
	
	#if no transition matrix is included
	if(tmat==F){	
	
	if(is.character(mat)==F)
	stop('mat is not a character matrix')
				
	#fn: first-order Markov transition matrix
	transition_matrix<-function(x) {
    tt<-table(c(x[-nrow(x),]),c(x[-1,]))
    return(tt/colSums(tt))	}
	
	#compute transition matrix
    qmat<-transition_matrix(mat)    
    
    #probability to/from gap==0
    if(indel==F) qmat['-',]<-qmat[,'-']<-0
    
    #probability to/from gap!=0
    else qmat<-qmat
    }
    
    else qmat<-mat
    
    #align training alignment to seed
    new_al<-aphid::align(seed,al)
    rownames(new_al)[which(!rownames(new_al)%in%rownames(al))]<-'Seed'
    seed_al<-new_al[,which(new_al['Seed',]%in%LETTERS)]
    
    ##training alignment from single participant
    if(training==1){
    	
    #% polymorphisms at each site
    ref_noncons<-lapply(seq_along(founder_seqs),function(i){
    	x<-seed_al[which(rownames(seed_al)%in%founder_seqs[[i]]),]
    	c(1-sapply(apply(x,2,table),max)/nrow(x))
    	})
	}
	
	##training alignment from multiple participants
	else{
	
	#equalize number of clusters in each MF
	max_clusters<-max(sapply(founder_seqs,length))
	founder_seqs<-lapply(founder_seqs,function(j){
		c(j,as.list(rep(NA, max_clusters-length(j))))
	})
	
	#% polymorphisms at each site
	c()->ref_nc
	c()->ref_noncons
	l<-length(founder_seqs[[1]])
	for(f in 1:l){
	ref_nc[[f]]<-sapply(founder_seqs,function(j){
			x<-seed_al[which(rownames(seed_al)%in%j[[f]]),]
			if(nrow(x)==0) rep(0,ncol(x))
			else 
			c(1-sapply(apply(x,2,table),max)/nrow(x))
			})
			if(founder_max==T) ref_noncons[[f]]<-apply(ref_nc[[f]],1,max)
			else ref_noncons[[f]]<-apply(ref_nc[[f]],1,sample,1)
		}	
	}
	
	#run simulations
	fn_sim_seqs<-function(clus){
		#progress bar
		pb <- txtProgressBar(min = 0,max=length(seed))
		print(paste('simulations progress...',clus))
		simseqs<-sapply(seq_along(seed),function(i){
			#progress
			setTxtProgressBar(pb,i)

			state<-grep(seed[i],rownames(qmat))
			new_qmat<-qmat[state,]
			new_qmat[state]<-1-ref_noncons[[clus]][i]
			freq_qmat<-ifelse(sum(new_qmat[-state])!=0,
			ref_noncons[[clus]][i]/sum(new_qmat[-state]),0)
			new_qmat[-state]<-new_qmat[-state]*freq_qmat
			new_states<-apply(rmultinom(n,1,new_qmat),2,which.max)
			names(new_qmat)[as.numeric(new_states)]
		})
		close(pb)

		rownames(simseqs)<-sapply('t',paste0,1:n,LETTERS[clus])
		return(simseqs)
	}
	
	sim_seq<-lapply(seq_along(ref_noncons), fn_sim_seqs)
	
	#return prescribed proportions of sequences in each alignment
	if(dif_prop==T){
	sim_seqs<-lapply(seq_along(sim_seq),function(r){
		x<-nrow(sim_seq[[r]])*prop[r]
		sim_seq[[r]][sample(nrow(sim_seq[[r]]),x),]
	})	}
	else sim_seqs<-sim_seq		
		
		#convert to sequence list
		seq_mat<-as.data.frame(rbind(seed,do.call("rbind", sim_seqs)))
		seqs<-as.list(sapply(1:nrow(seq_mat),function(i){seqinr::c2s(seq_mat[i,])}))
		seq_names<-c('Seed',rownames(seq_mat)[-1])
		names(seqs)<-seq_names
				
		#prob !=consensus at each site (simulated)
		sim_noncon<-1-sapply(apply(seq_mat[-1,],2,table),
		max)/(nrow(seq_mat)-1)
		
		#founders: prob !=consensus at each site (simulated)
		sim_noncon_founder<-lapply(seq_along(ref_noncons),function(o){
			clus_mat<-seq_mat[grep(LETTERS[o],rownames(seq_mat)),]
			1-sapply(apply(clus_mat,2,table),max)/(nrow(clus_mat))
		})
		
		#write sequences to fasta file
		#sequences may need to be re-aligned
		if(write==T){
			seqinr::write.fasta(seqs,seq_names,
					file=paste0(name,'.fas'))
					}
			
			#pairwise distances in simulated sequences
			aa_sim<-as.AAbin(seqs)
			aa_sim_founder<-lapply(seq_along(ref_noncons),function(x)
				aa_sim[grep(LETTERS[x],seq_names)])	
			
			#diversity in simulated alignments
			sim_founder_dists<-lapply(aa_sim_founder,dist.ml)
			
			#diversity in training alignment
			seed_row<-grep('Seed',rownames(seed_al))
			train_dist<-dist.ml(as.AAbin(seed_al[-seed_row,]))			
			
			#polymorphic sites per simulated sequence
			sim_founder_polies<-lapply(aa_sim_founder,function(p){
				m<-as.character(as.matrix(p))
				n<-apply(m,1,function(r){
				length(which(apply(rbind(r,seed),2,
				function(s) length(table(s)))>1))
					})
				})
				
			#polymorphic sites per training sequence
			train_consensus<-bio3d::consensus(seed_al[-seed_row,])$seq
			train_polies<-apply(seed_al[-seed_row,],1,function(r){
				length(which(apply(rbind(r,train_consensus),2,
				function(s) length(table(s)))>1))
				})
			
			return(list(seqs=seqs,names=seq_names,
				ref_noncons=ref_noncons,
				sim_noncon=sim_noncon,
				sim_noncon_founder=sim_noncon_founder,
				sim_founder_dists=sim_founder_dists,
				sim_founder_polies=sim_founder_polies,
				aa_sim=aa_sim,
				aa_sim_founder=aa_sim_founder))
		}